Python API reference
====================

The GO-PCA Python API currently consists of five classes that contain GO-PCA
parameter settings, perform the analysis, and represent the results:

.. currentmodule:: gopca

.. autosummary::

    GOPCAConfig
    GOPCAParams
    GOPCA
    GOPCARun
    GOPCASignatureMatrix
    GOPCASignature

.. toctree::
    :hidden:
    :maxdepth: 2

    config
    params
    gopca
    run
    signature
    signature_matrix